# Generated by Django 5.2.6 on 2025-09-23 05:11

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="SeedRevision",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "seed_slug",
                    models.CharField(
                        help_text="Unique identifier for the seed", max_length=255
                    ),
                ),
                (
                    "revision",
                    models.IntegerField(help_text="Version number of the loaded seed"),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
            ],
            options={
                "verbose_name": "seed Revision",
                "verbose_name_plural": "seed Revisions",
                "db_table": "django_seed_manager_revision",
                "indexes": [
                    models.Index(
                        fields=["seed_slug"], name="django_seed_seed_sl_6adca8_idx"
                    ),
                    models.Index(
                        fields=["seed_slug", "revision"],
                        name="django_seed_seed_sl_4a1cb0_idx",
                    ),
                ],
            },
        ),
    ]
